@@ -13,13 +13,11 @@ class FoodDialog : public QDialog
 
 public:
     explicit FoodDialog(QWidget *parent = 0);
-    void load();
+
 
 private:
     XML *xml;
 
-
-
     QVBoxLayout *vLayout;
 
     QStandardItemModel *modelName;
@@ -37,6 +35,7 @@ private:
 
 private slots:
     void save();
+    void load(QString type);
 };
 
 #endif // FOODDIALOG_H
