@@ -222,10 +222,13 @@ void InfoWindow::loadExercise(QString name)
 
     while(!list.isEmpty())
     {
-        weight[i] = list.takeFirst();
-        reps[i] = list.takeFirst();
-        status[i] = list.takeFirst();
 
+        weight[i] = list.takeFirst();
+        qDebug () << "load exercise a";
+        reps[i] = list.takeFirst();
+        qDebug () << "load exercise b";
+        status[i] = list.takeFirst();
+        qDebug () << "load exercise c";
         i++;
     }
     qDebug () << "load exercise 5";
