@@ -18,7 +18,6 @@ ListWindow::ListWindow(QWidget *parent) :
     lstExercises->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(lstExercises, SIGNAL(customContextMenuRequested(const QPoint &)),SLOT(showContextMenuForWidget(const QPoint &)));
 
-
     createActions();
     createMenu();
 
@@ -247,7 +246,7 @@ void ListWindow::editItem()
         list = xml->loadProgram(str);
         qDebug() << "ListWindow::editItem 2";
         npw = new NewProgramWindow(this);
-        qDebug() << "ListWindow::editItem 3";
+        qDebug() << "ListWindow::editItem 3" << str;
         npw->load(str,list);
         npw->show();
         qDebug() << "ListWindow::editItem 4";
