@@ -41,8 +41,7 @@ private:
     QMaemo5ListPickSelector *selectorReps;
     QMaemo5ListPickSelector *selectorVar;
 
-    QHBoxLayout *hLayout;
-    QVBoxLayout *buttonLayout;
+    QVBoxLayout *vLayout;
 
     QString group;
     QString exName;
