@@ -40,7 +40,7 @@ public:
     void removeHistory(QString name, QString date);
 
     void saveFood(QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat);
-    QList<QString> openIngredients();
+    QList<QString> openIngredients(QString type);
     void saveEatenFood(QString kcal, QString protein, QString carbohydrate, QString fat);
     QList <int> getTodaysCalories();
     void getMeanCalories();
